Exports the build_site function which stitches together the high-level
steps of building the output static site: parsing the posts
(crate::post), rendering index and post pages (crate::write),
copying the static source directory into the static output directory, and
generating the Atom feed.
Enums
- Error
- The error type for building a site. Errors can be during parsing, writing, cleaning output directories, parsing template files, and other I/O.
Functions
- build_
site - Builds the site from a
Configobject. This calls intoPostParser::parse_posts,Writer::write_posts, andwrite_feedwhich do the heavy-lifting. This function also copies the static assets from source directory to the output directory.