Module feed

Module feed 

Support for creating Atom feeds from a list of posts.

Structs

FeedConfig
Bundled configuration for creating a feed.

Enums

Error
Represents a problem creating a feed. Variants inlude I/O, Atom, and date-time parsing issues.

Functions

write_feed
Creates a feed from some configuration (FeedConfig) and a list of Posts and writes the result to a std::io::Write. This function takes ownership of the provided FeedConfig.