Module parser

Module parser 

Defines the Post, Parser, and Error types. Also defines the logic for parsing posts from the file system into memory. See the Post::to_value and Post::summarize for details on how posts are converted into template values.

Structs

Parser
Parses Post objects from source files.

Enums

Error
Represents an error parsing a Post object.

Type Aliases

Result
Represents the result of a Post-parse operation.