pub struct Tag {
pub name: String,
pub url: Url,
}Expand description
Represents a crate::post::Post tag. On parsing a post from YAML, only
the name field is parsed while the url field is left empty. The URL
field must be filled in later based on the index_base_url and the tag
name.
Fields
name: StringThe tag’s name. This should be slugified so e.g., macOS and MacOS
resolve to the same value, and also so the field can be dropped into a
Url.
url: UrlThe URL for the tag’s first index page. Given an index_base_url,
this should look something like
{index_base_url}/{tag_name}/index.html.