Contains the logic for collecting and consolidating the program’s configuration.
Structs
- Author
- Represents an author.
- Config
- The complete configuration object, ready to be passed to
crate::build::build_site.
Enums
- Error
- The error type for fallible configuration operations, namely parsing configuration files.